
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TriangleAlert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-triangle-alert'], 'items': [{'path': {'d': 'm21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3'}}, {'path': {'d': 'M12 9v4'}}, {'path': {'d': 'M12 17h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
