
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mails(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mails'], 'items': [{'path': {'d': 'M17 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-8a2 2 0 0 1 1-1.732'}}, {'path': {'d': 'm22 5.5-6.419 4.179a2 2 0 0 1-2.162 0L7 5.5'}}, {'rect': {'x': '7', 'y': '3', 'width': '15', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
