
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Warehouse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-warehouse'], 'items': [{'path': {'d': 'M18 21V10a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v11'}}, {'path': {'d': 'M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 1.132-1.803l7.95-3.974a2 2 0 0 1 1.837 0l7.948 3.974A2 2 0 0 1 22 8z'}}, {'path': {'d': 'M6 13h12'}}, {'path': {'d': 'M6 17h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
