
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FunnelX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-funnel-x'], 'items': [{'path': {'d': 'M12.531 3H3a1 1 0 0 0-.742 1.67l7.225 7.989A2 2 0 0 1 10 14v6a1 1 0 0 0 .553.895l2 1A1 1 0 0 0 14 21v-7a2 2 0 0 1 .517-1.341l.427-.473'}}, {'path': {'d': 'm16.5 3.5 5 5'}}, {'path': {'d': 'm21.5 3.5-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
