
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EyeClosed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-eye-closed'], 'items': [{'path': {'d': 'm15 18-.722-3.25'}}, {'path': {'d': 'M2 8a10.645 10.645 0 0 0 20 0'}}, {'path': {'d': 'm20 15-1.726-2.05'}}, {'path': {'d': 'm4 15 1.726-2.05'}}, {'path': {'d': 'm9 18 .722-3.25'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
