
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BellDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell-dot'], 'items': [{'path': {'d': 'M10.268 21a2 2 0 0 0 3.464 0'}}, {'path': {'d': 'M13.916 2.314A6 6 0 0 0 6 8c0 4.499-1.411 5.956-2.74 7.327A1 1 0 0 0 4 17h16a1 1 0 0 0 .74-1.673 9 9 0 0 1-.585-.665'}}, {'circle': {'cx': '18', 'cy': '8', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
