
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PhoneMissed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-phone-missed'], 'items': [{'path': {'d': 'm16 2 6 6'}}, {'path': {'d': 'm22 2-6 6'}}, {'path': {'d': 'M13.832 16.568a1 1 0 0 0 1.213-.303l.355-.465A2 2 0 0 1 17 15h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2A18 18 0 0 1 2 4a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-.8 1.6l-.468.351a1 1 0 0 0-.292 1.233 14 14 0 0 0 6.392 6.384'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
