
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Videotape(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-videotape'], 'items': [{'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M2 8h20'}}, {'circle': {'cx': '8', 'cy': '14', 'r': '2'}}, {'path': {'d': 'M8 12h8'}}, {'circle': {'cx': '16', 'cy': '14', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
