
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Podcast(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-podcast'], 'items': [{'path': {'d': 'M13 17a1 1 0 1 0-2 0l.5 4.5a0.5 0.5 0 0 0 1 0z', 'fill': 'currentColor'}}, {'path': {'d': 'M16.85 18.58a9 9 0 1 0-9.7 0'}}, {'path': {'d': 'M8 14a5 5 0 1 1 8 0'}}, {'circle': {'cx': '12', 'cy': '11', 'r': '1', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
