
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BrushCleaning(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-brush-cleaning'], 'items': [{'path': {'d': 'm16 22-1-4'}}, {'path': {'d': 'M19 13.99a1 1 0 0 0 1-1V12a2 2 0 0 0-2-2h-3a1 1 0 0 1-1-1V4a2 2 0 0 0-4 0v5a1 1 0 0 1-1 1H6a2 2 0 0 0-2 2v.99a1 1 0 0 0 1 1'}}, {'path': {'d': 'M5 14h14l1.973 6.767A1 1 0 0 1 20 22H4a1 1 0 0 1-.973-1.233z'}}, {'path': {'d': 'm8 22 1-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
