
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileClock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-clock'], 'items': [{'path': {'d': 'M16 22h2a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v2.85'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M8 14v2.2l1.6 1'}}, {'circle': {'cx': '8', 'cy': '16', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
