
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImagePlay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-play'], 'items': [{'path': {'d': 'M15 15.003a1 1 0 0 1 1.517-.859l4.997 2.997a1 1 0 0 1 0 1.718l-4.997 2.997a1 1 0 0 1-1.517-.86z'}}, {'path': {'d': 'M21 12.17V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6'}}, {'path': {'d': 'm6 21 5-5'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
