
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def KeyRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-key-round'], 'items': [{'path': {'d': 'M2.586 17.414A2 2 0 0 0 2 18.828V21a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1h1a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1h.172a2 2 0 0 0 1.414-.586l.814-.814a6.5 6.5 0 1 0-4-4z'}}, {'circle': {'cx': '16.5', 'cy': '7.5', 'r': '.5', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
