
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scale3d(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scale-3d'], 'items': [{'path': {'d': 'M5 7v11a1 1 0 0 0 1 1h11'}}, {'path': {'d': 'M5.293 18.707 11 13'}}, {'circle': {'cx': '19', 'cy': '19', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '5', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
