
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def KeyboardMusic(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-keyboard-music'], 'items': [{'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M6 8h4'}}, {'path': {'d': 'M14 8h.01'}}, {'path': {'d': 'M18 8h.01'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M6 12v4'}}, {'path': {'d': 'M10 12v4'}}, {'path': {'d': 'M14 12v4'}}, {'path': {'d': 'M18 12v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
