
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Helicopter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-helicopter'], 'items': [{'path': {'d': 'M11 17v4'}}, {'path': {'d': 'M14 3v8a2 2 0 0 0 2 2h5.865'}}, {'path': {'d': 'M17 17v4'}}, {'path': {'d': 'M18 17a4 4 0 0 0 4-4 8 6 0 0 0-8-6 6 5 0 0 0-6 5v3a2 2 0 0 0 2 2z'}}, {'path': {'d': 'M2 10v5'}}, {'path': {'d': 'M6 3h16'}}, {'path': {'d': 'M7 21h14'}}, {'path': {'d': 'M8 13H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
