
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Stamp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-stamp'], 'items': [{'path': {'d': 'M14 13V8.5C14 7 15 7 15 5a3 3 0 0 0-6 0c0 2 1 2 1 3.5V13'}}, {'path': {'d': 'M20 15.5a2.5 2.5 0 0 0-2.5-2.5h-11A2.5 2.5 0 0 0 4 15.5V17a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1z'}}, {'path': {'d': 'M5 22h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
