
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SwatchBook(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-swatch-book'], 'items': [{'path': {'d': 'M11 17a4 4 0 0 1-8 0V5a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2Z'}}, {'path': {'d': 'M16.7 13H19a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H7'}}, {'path': {'d': 'M 7 17h.01'}}, {'path': {'d': 'm11 8 2.3-2.3a2.4 2.4 0 0 1 3.404.004L18.6 7.6a2.4 2.4 0 0 1 .026 3.434L9.9 19.8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
