
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def House(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house'], 'items': [{'path': {'d': 'M15 21v-8a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v8'}}, {'path': {'d': 'M3 10a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
