
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ALargeSmall(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-a-large-small'], 'items': [{'path': {'d': 'm15 16 2.536-7.328a1.02 1.02 1 0 1 1.928 0L22 16'}}, {'path': {'d': 'M15.697 14h5.606'}}, {'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M3.304 13h6.392'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
