
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileTypeCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-type-corner'], 'items': [{'path': {'d': 'M12 22h6a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v6'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M3 16v-1.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5V16'}}, {'path': {'d': 'M6 22h2'}}, {'path': {'d': 'M7 14v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
