
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hospital(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hospital'], 'items': [{'path': {'d': 'M12 7v4'}}, {'path': {'d': 'M14 21v-3a2 2 0 0 0-4 0v3'}}, {'path': {'d': 'M14 9h-4'}}, {'path': {'d': 'M18 11h2a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-9a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'M18 21V5a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
