
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptEuro(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-euro'], 'items': [{'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z'}}, {'path': {'d': 'M8 12h5'}}, {'path': {'d': 'M16 9.5a4 4 0 1 0 0 5.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
