
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LogOut(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-log-out'], 'items': [{'path': {'d': 'm16 17 5-5-5-5'}}, {'path': {'d': 'M21 12H9'}}, {'path': {'d': 'M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
