
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sprout(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sprout'], 'items': [{'path': {'d': 'M14 9.536V7a4 4 0 0 1 4-4h1.5a.5.5 0 0 1 .5.5V5a4 4 0 0 1-4 4 4 4 0 0 0-4 4c0 2 1 3 1 5a5 5 0 0 1-1 3'}}, {'path': {'d': 'M4 9a5 5 0 0 1 8 4 5 5 0 0 1-8-4'}}, {'path': {'d': 'M5 21h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
