
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Dessert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-dessert'], 'items': [{'path': {'d': 'M10.162 3.167A10 10 0 0 0 2 13a2 2 0 0 0 4 0v-1a2 2 0 0 1 4 0v4a2 2 0 0 0 4 0v-4a2 2 0 0 1 4 0v1a2 2 0 0 0 4-.006 10 10 0 0 0-8.161-9.826'}}, {'path': {'d': 'M20.804 14.869a9 9 0 0 1-17.608 0'}}, {'circle': {'cx': '12', 'cy': '4', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
