
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Download(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-download'], 'items': [{'path': {'d': 'M12 15V3'}}, {'path': {'d': 'M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4'}}, {'path': {'d': 'm7 10 5 5 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
