
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Factory(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-factory'], 'items': [{'path': {'d': 'M12 16h.01'}}, {'path': {'d': 'M16 16h.01'}}, {'path': {'d': 'M3 19a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V8.5a.5.5 0 0 0-.769-.422l-4.462 2.844A.5.5 0 0 1 15 10.5v-2a.5.5 0 0 0-.769-.422L9.77 10.922A.5.5 0 0 1 9 10.5V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2z'}}, {'path': {'d': 'M8 16h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
