
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Egg(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-egg'], 'items': [{'path': {'d': 'M12 2C8 2 4 8 4 14a8 8 0 0 0 16 0c0-6-4-12-8-12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
