
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-down'], 'items': [{'path': {'d': 'M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z'}}, {'path': {'d': 'M12 10v6'}}, {'path': {'d': 'm15 13-3 3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
