
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Truck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-truck'], 'items': [{'path': {'d': 'M14 18V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v11a1 1 0 0 0 1 1h2'}}, {'path': {'d': 'M15 18H9'}}, {'path': {'d': 'M19 18h2a1 1 0 0 0 1-1v-3.65a1 1 0 0 0-.22-.624l-3.48-4.35A1 1 0 0 0 17.52 8H14'}}, {'circle': {'cx': '17', 'cy': '18', 'r': '2'}}, {'circle': {'cx': '7', 'cy': '18', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
