
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sofa(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sofa'], 'items': [{'path': {'d': 'M20 9V6a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v3'}}, {'path': {'d': 'M2 16a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5a2 2 0 0 0-4 0v1.5a.5.5 0 0 1-.5.5h-11a.5.5 0 0 1-.5-.5V11a2 2 0 0 0-4 0z'}}, {'path': {'d': 'M4 18v2'}}, {'path': {'d': 'M20 18v2'}}, {'path': {'d': 'M12 4v9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
