
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TestTubeDiagonal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-test-tube-diagonal'], 'items': [{'path': {'d': 'M21 7 6.82 21.18a2.83 2.83 0 0 1-3.99-.01a2.83 2.83 0 0 1 0-4L17 3'}}, {'path': {'d': 'm16 2 6 6'}}, {'path': {'d': 'M12 16H4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
