
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lectern(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lectern'], 'items': [{'path': {'d': 'M16 12h3a2 2 0 0 0 1.902-1.38l1.056-3.333A1 1 0 0 0 21 6H3a1 1 0 0 0-.958 1.287l1.056 3.334A2 2 0 0 0 5 12h3'}}, {'path': {'d': 'M18 6V3a1 1 0 0 0-1-1h-3'}}, {'rect': {'width': '8', 'height': '12', 'x': '8', 'y': '10', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
