
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Music4(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-music-4'], 'items': [{'path': {'d': 'M9 18V5l12-2v13'}}, {'path': {'d': 'm9 9 12-2'}}, {'circle': {'cx': '6', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '18', 'cy': '16', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
