
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Replace(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-replace'], 'items': [{'path': {'d': 'M14 4a1 1 0 0 1 1-1'}}, {'path': {'d': 'M15 10a1 1 0 0 1-1-1'}}, {'path': {'d': 'M21 4a1 1 0 0 0-1-1'}}, {'path': {'d': 'M21 9a1 1 0 0 1-1 1'}}, {'path': {'d': 'm3 7 3 3 3-3'}}, {'path': {'d': 'M6 10V5a2 2 0 0 1 2-2h2'}}, {'rect': {'x': '3', 'y': '14', 'width': '7', 'height': '7', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
