
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Brush(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-brush'], 'items': [{'path': {'d': 'm11 10 3 3'}}, {'path': {'d': 'M6.5 21A3.5 3.5 0 1 0 3 17.5a2.62 2.62 0 0 1-.708 1.792A1 1 0 0 0 3 21z'}}, {'path': {'d': 'M9.969 17.031 21.378 5.624a1 1 0 0 0-3.002-3.002L6.967 14.031'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
