
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Megaphone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-megaphone'], 'items': [{'path': {'d': 'M11 6a13 13 0 0 0 8.4-2.8A1 1 0 0 1 21 4v12a1 1 0 0 1-1.6.8A13 13 0 0 0 11 14H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M6 14a12 12 0 0 0 2.4 7.2 2 2 0 0 0 3.2-2.4A8 8 0 0 1 10 14'}}, {'path': {'d': 'M8 6v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
