
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareRoundCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-round-corner'], 'items': [{'path': {'d': 'M21 11a8 8 0 0 0-8-8'}}, {'path': {'d': 'M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
