
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Network(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-network'], 'items': [{'rect': {'x': '16', 'y': '16', 'width': '6', 'height': '6', 'rx': '1'}}, {'rect': {'x': '2', 'y': '16', 'width': '6', 'height': '6', 'rx': '1'}}, {'rect': {'x': '9', 'y': '2', 'width': '6', 'height': '6', 'rx': '1'}}, {'path': {'d': 'M5 16v-3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v3'}}, {'path': {'d': 'M12 12V8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
