
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PillBottle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pill-bottle'], 'items': [{'path': {'d': 'M18 11h-4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h4'}}, {'path': {'d': 'M6 7v13a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V7'}}, {'rect': {'width': '16', 'height': '5', 'x': '4', 'y': '2', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
