
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bath(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bath'], 'items': [{'path': {'d': 'M10 4 8 6'}}, {'path': {'d': 'M17 19v2'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M7 19v2'}}, {'path': {'d': 'M9 5 7.621 3.621A2.121 2.121 0 0 0 4 5v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
