
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Goal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-goal'], 'items': [{'path': {'d': 'M12 13V2l8 4-8 4'}}, {'path': {'d': 'M20.561 10.222a9 9 0 1 1-12.55-5.29'}}, {'path': {'d': 'M8.002 9.997a5 5 0 1 0 8.9 2.02'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
