
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RectangleGoggles(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rectangle-goggles'], 'items': [{'path': {'d': 'M20 6a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-4a2 2 0 0 1-1.6-.8l-1.6-2.13a1 1 0 0 0-1.6 0L9.6 17.2A2 2 0 0 1 8 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
